import QtQuick 1.0
import com.nokia.meego 1.0
import myExplorer.types 1.0

Dialog
{
    width: parent.width - 10

    property string titleText: ""
    property string fileName: ""
    property string imageName: ""
    property string typeText: ""
    property string pathText: ""
    property string sizeText: ""
    property string savedText: ""
    property bool isReadOnly: false
    property bool isHidden: false

    title: Text { font.pixelSize: 30; font.bold: true; color: "white"; text: titleText; anchors.bottomMargin: 40;
        anchors.horizontalCenter: parent.horizontalCenter }

    content: Column
    {
        width: parent.width

        Row {
            width: parent.width

            Column {
                id: leftCol
                spacing: 10

                Row {
                    height: 15
                    Text { text: " "; }
                }

                Image { id: typeImage; source: imageName }
                Text { font.pixelSize: 24; color: "lightgray"; text: "Type: "; }
                Text { font.pixelSize: 24; color: "lightgray"; text: "Path: "; }
                Text { font.pixelSize: 24; color: "lightgray"; text: "Size: "; }
                Text { id: savedLabel; font.pixelSize: 24; color: "lightgray"; text: "Saved: "; }
            }

            Column {
                spacing: 10

                Row {
                    height: 15
                    Text { text: " "; }
                }

                Text { height: typeImage.height; font.pixelSize: 24; color: "white"; text: fileName; verticalAlignment: Text.AlignVCenter; }

                Text { font.pixelSize: 24; color: "white"; text: typeText; }
                Text { font.pixelSize: 24; color: "white"; text: pathText; }
                Text { font.pixelSize: 24; color: "white"; text: sizeText; }
                Text { font.pixelSize: 24; color: "white"; text: savedText; }
            }
        }

        Row {
            height: 15
            Text { text: " "; }
        }

        Row {
            CheckBox { id: cbRo; checked: isReadOnly; onClicked: checked = !checked; }
            Text { height: cbRo.height; font.pixelSize: 24; color: "lightgray"; text: "Read-only"; verticalAlignment: Text.AlignVCenter; }
            Text { text: " "; width: 30 }
            CheckBox { id: cbHidden; checked: isHidden; onClicked: checked = !checked; }
            Text { height: cbHidden.height; font.pixelSize: 24; color: "lightgray"; text: "Hidden"; verticalAlignment: Text.AlignVCenter; }
        }

        Row {
            height: 25
            Text { text: " "; }
        }
    }

    buttons: Button { text: "Close"; anchors.horizontalCenter: parent.horizontalCenter; onClicked: reject(); }

    signal privateClicked
    onPrivateClicked: {}

    onRejected: app.OnFileDetailsDlgClosed();

    function updateSize(size) { sizeText = size; }

    function showDialog(title, name, image, type, path, size, saved, isRo, isHid)
    {
        titleText = title;
        fileName = name;
        imageName = image;
        typeText = type;
        pathText = path;
        sizeText = size;
        savedText = saved;
        isReadOnly = isRo;
        isHidden = isHid;

        open();
    }
}
