import QtQuick 1.0
import com.nokia.meego 1.0
import myExplorer.types 1.0

Page {
    tools: folderTools

    function open(popup)
    {
        theForm.StopScroll();
        popup.open();
    }

    ToolBarLayout {
        id: folderTools
        visible: false

        MilToolButton {
            platformIconId: "toolbar-back"
            onClicked: theForm.cmdBack();
            tipText: qsTr("Back");
        }

        MilToolButton {
            platformIconId: "toolbar-search"
            onClicked: sbox.show(); //app.OnFolderCmd(109);
            tipText: qsTr("Filter / Search")
        }

        MilToolButton {
            platformIconId: "toolbar-list"
            onClicked: open(selectMenu);
            tipText: qsTr("Select")
        }

        MilToolButton {
            iconSource: app.InvertedTheme() ? "qrc:/resources/tbicons/paste.svg" : "qrc:/resources/tbicons/paste_inverse.svg"
            onClicked: app.OnFolderCmd(112);
            tipText: qsTr("Paste")
            enabled: theForm.pasteEnabled
        }


        MilToolButton {
            platformIconId: "toolbar-view-menu"
            anchors.right: (parent === undefined) ? undefined : parent.right
            onClicked: open(folderMenu);
            tipText: qsTr("Show menu")
        }
    }

    TitleBar {
        id: titleBar
        small: true
        titleText: theForm.titleText
        inverted: app.InvertedTheme();

        MouseArea {
            anchors.fill: parent
            onClicked: theForm.cmdShowTreeDialog();
        }

        function show() {
            visible = true;
            y = 0;
        }

        function hide() {
            y = -titleBar.height;
            visible = false;
        }
    }

    Item {
        id: menus
        anchors.fill: parent
        visible: false

        Menu {
            id: folderMenu
            MenuLayout {
                //MenuItem { text: qsTr("Select"); onClicked: selectMenu.open(); }
                MenuItem { text: qsTr("New Folder"); onClicked: app.OnFolderCmd(108); }
                MenuItem { text: qsTr("Refresh"); onClicked: app.OnFolderCmd(107); }
                //MenuItem { text: qsTr("Folder Path"); onClicked: theForm.cmdShowTreeDialog(); }
                MenuItem { text: qsTr("View Options"); onClicked: dlgViewOptions.openDlg(); }
                MenuItem { text: qsTr("Help"); onClicked: appWindow.showHelp("folder_form.html"); }
            }
        }

        ContextMenu {
            id: folderMenu1
            MenuLayout {
                MenuItem { text: qsTr("Details"); onClicked: app.OnFolderCmd(104); }
                MenuItem { text: qsTr("Rename"); onClicked: app.OnFolderCmd(105); }
                MenuItem { text: qsTr("Copy"); onClicked: app.OnFolderCmd(114); }
                MenuItem { text: qsTr("Cut"); onClicked: app.OnFolderCmd(115); }
                MenuItem { text: qsTr("Delete"); onClicked: app.OnFolderCmd(106); }
            }

            onStatusChanged: menus.statusChanged(status);
        }

        ContextMenu {
            id: folderMenu2
            MenuLayout {
                MenuItem { text: qsTr("Details"); onClicked: app.OnFolderCmd(104); }
                MenuItem { text: qsTr("Copy"); onClicked: app.OnFolderCmd(114); }
                MenuItem { text: qsTr("Cut"); onClicked: app.OnFolderCmd(115); }
                MenuItem { text: qsTr("Delete"); onClicked: app.OnFolderCmd(106); }
            }

            onStatusChanged: menus.statusChanged(status);
        }

        ContextMenu {
            id: folderMenu3
            MenuLayout {
                MenuItem { text: qsTr("Details"); onClicked: app.OnFolderCmd(104); }
                MenuItem { text: qsTr("Copy"); onClicked: app.OnFolderCmd(114); }
            }

            onStatusChanged: menus.statusChanged(status);
        }

        ContextMenu {
            id: folderMenu4
            MenuLayout {
                MenuItem { text: qsTr("New Folder"); onClicked: app.OnFolderCmd(108); }
            }

            onStatusChanged: menus.statusChanged(status);
        }

        ContextMenu {
            id: folderMenu5
            MenuLayout {
                MenuItem { text: qsTr("Paste"); onClicked: app.OnFolderCmd(112); }
                MenuItem { text: qsTr("New Folder"); onClicked: app.OnFolderCmd(108); }
            }

            onStatusChanged: menus.statusChanged(status);
        }

        function statusChanged(status)
        {
             if (status == DialogStatus.Closing)
                theForm.CtxMenuClosed();
        }
    }

    Item {
        id: dlg
        visible: false

        SelectionDialog
        {
            id: dlgTree
            titleText: "Go to parent folder"
            selectedIndex: 0

            model: ListModel {
                id: treeModel
            }

            function clearItems() { treeModel.clear(); }
            function addItem(folderName) { treeModel.append({"name":folderName}) }

            onAccepted: {
                theForm.cmdResetSearchBox();
                app.OnTreeDlgAccepted(selectedIndex);
            }
        }
    }

    QmlFolderForm {
        id: theForm
        anchors.top: titleBar.bottom;
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom

        function cmdBack() { app.OnFolderBack(); }

        function cmdShowTreeDialog() { dlgTree.selectedIndex = 0; open(dlgTree); }
        function cmdAddTreeItem(item) { dlgTree.addItem(item); }
        function cmdClearTreeItems() { dlgTree.clearItems(); }

        function cmdShowFolderMenu1() { open(folderMenu1); }
        function cmdShowFolderMenu2() { open(folderMenu2); }
        function cmdShowFolderMenu3() { open(folderMenu3); }
        function cmdShowFolderMenu4() { open(folderMenu4); }
        function cmdShowFolderMenu5() { open(folderMenu5); }

        function cmdShowRenameDialog(fileName)
        {
            if (dlgRename.status != Loader.Ready)
            {
                //console.log("Loading RenameDialog");
                dlgRename.source = "RenameDialog.qml";
            }

            dlgRename.item.fileName = fileName;
            open(dlgRename.item);
        }

        function cmdShowNewFolderDialog(folderName)
        {
            if (dlgNewFolder.status != Loader.Ready)
            {
                //console.log("Loading NewFolderDialog");
                dlgNewFolder.source = "NewFolderDialog.qml";
            }

            dlgNewFolder.item.folderName = folderName;
            open(dlgNewFolder.item);
        }

        function cmdShowFilterDialog(pattern)
        {
            if (dlgFilter.status != Loader.Ready)
            {
                //console.log("Loading FilterDialog");
                dlgFilter.source = "FilterDialog.qml";
            }

            dlgFilter.item.pattern = pattern;
            open(dlgFilter.item);
        }

        function cmdShowShareSelDialog() { dlgSelShare.selectedIndex = 0; open(dlgSelShare); }
        function cmdAddShareSel(share) { dlgSelShare.addShare(share); }
        function cmdClearShares() { dlgSelShare.clearShares(); }

        function cmdShowLoginDialog(uncName, userName, password, remember)
        {
            if (dlgLogin.status != Loader.Ready)
            {
                //console.log("Loading LoginDialog");
                dlgLogin.source = "LoginDialog.qml";
            }

            dlgLogin.item.titleText = uncName;
            dlgLogin.item.userName = userName;
            dlgLogin.item.password = password;
            dlgLogin.item.rememberPassword = remember;

            open(dlgLogin.item);
        }

        function cmdShowPasswordDialog()
        {
            if (dlgPassword.status != Loader.Ready)
            {
                //console.log("Loading PasswordDialog");
                dlgPassword.source = "PasswordDialog.qml";
            }

            dlgPassword.item.showDialog();
        }

        function cmdShowRenameExtWarning() { open(msgRenameExt); }
        function cmdShowRenameRoWarning(msg) { msgRenameRo.msg = msg; open(msgRenameRo); }
        function cmdShowDeleteWarning(msg) { msgDelete.msg = msg; open(msgDelete); }
        function cmdShowSelDeleteWarning(msg) { msgSelDelete.msg = msg; open(msgSelDelete); }

        function cmdResetSearchBox() {
            if (sbox.visible)
                sbox.close();
            sbox.clear();
        }
    }

    MilSearchBox {
        id: sbox
        backButton: true
        platformInverted: app.InvertedTheme();
        anchors { left: parent.left; right: parent.right; bottom: parent.bottom; }
        visible: false;
        placeHolderText: "Enter search pattern"
        property bool isActive: true

        function show() {
            if (sbox.visible)
                return;
            theForm.StopScroll();
            theForm.anchors.bottom = sbox.top
            appWindow.showToolBar = false;
            titleBar.hide();
            sbox.visible = true;
            sbox.showKbd();
        }

        function close() {
            if (!sbox.visible)
                return;
            theForm.StopScroll();
            theForm.anchors.bottom = parent.bottom
            sbox.visible = false;
            appWindow.showToolBar = true;
            titleBar.show();
        }

        function clear() {
            searchText = "";
        }

        onBackClicked: close();
        onSearchTextChanged: if (sbox.visible) theForm.OnSearchTextChanging(searchText.toString());
    }

    onStatusChanged: {
        theForm.StopScroll();

        if (sbox.visible && status === PageStatus.Activating) {
            appWindow.showToolBar = false;
            titleBar.hide();
        }
    }

    Component.onCompleted: app.OnFolderFormLoaded(theForm);
}

