import QtQuick 1.1
import com.nokia.meego 1.0
import QtWebKit 1.0
import myExplorer.types 1.0

Page {
    id: helpPage

    property string title: flickWebView.title
    property alias url: webView.url

    tools: commonTools

    ToolBarLayout {
        id: commonTools
        //visible: false

        MilToolButton {
            platformIconId: "toolbar-back"
            onClicked: appWindow.pageStack.pop();
            tipText: "Close help"
        }

        MilToolButton {
            platformIconId: "toolbar-previous"
            enabled: webView.back.enabled
            onClicked: webView.back.trigger();
            tipText: "Back"
        }

        MilToolButton {
            platformIconId: "toolbar-next"
            enabled: webView.forward.enabled
            onClicked: webView.forward.trigger();
            tipText: "Forward"
        }
    }

    Flickable {
        id: flickWebView
        anchors.fill: parent;
        contentWidth: webView.width
        contentHeight: webView.height
        pressDelay: 200

        property alias back: webView.back
        property alias title: webView.title


        QmlWebView
        {
            id: webView

            preferredWidth: flickWebView.width
            preferredHeight: flickWebView.height

            onUrlChanged: {
                //console.log("URL: " + webView.url);
                // got to topleft
                if (!anchorAnimation.running) {
                    flickWebView.contentX = 0
                    flickWebView.contentY = 0
                }
            }

            onScrollRequested: {
                anchorAnimation.toX = Math.min(width - flickWebView.width, scrollX);
                anchorAnimation.toY = Math.min(height - flickWebView.height, scrollY);
                anchorAnimation.running = true;
            }

            ParallelAnimation {
                id: anchorAnimation
                property alias toX: xanim.to
                property alias toY: yanim.to
                NumberAnimation {
                    id: yanim
                    target: flickWebView
                    property: "contentY"
                    to: 0
                    duration: 300
                    easing.type: Easing.InOutQuad
                }
                NumberAnimation {
                    id: xanim
                    target: flickWebView
                    property: "contentX"
                    to: 0
                    duration: 300
                    easing.type: Easing.InOutQuad
                }
            }
        }
    }

    ScrollDecorator
    {
        flickableItem: flickWebView
        anchors.right: parent.right
    }

    Component.onCompleted: console.log("Help form loaded");
    Component.onDestruction: console.log("Help form destroyed");
}

