import QtQuick 1.1
import com.nokia.meego 1.0
import myExplorer.types 1.0
import "Dynamic.js" as Dynamic

Page {
    tools: commonTools

    ToolBarLayout {
        id: commonTools
        visible: false

        MilToolButton {
            platformIconId: "toolbar-close"
            onClicked: appWindow.cmdExit();
            tipText: qsTr("Exit myExplorer")
        }

        MilToolButton {
            platformIconId: "toolbar-add"
            onClicked: cmdAddNetworkFolder();
            tipText: qsTr("Add network share")
        }

        MilToolButton {
            platformIconId: "toolbar-settings"
            onClicked: app.OnSettings();
            tipText: qsTr("Settings")
        }

        MilToolButton {
            platformIconId: "toolbar-view-menu"
            anchors.right: (parent === undefined) ? undefined : parent.right
            onClicked: menus.mainMenu.open();
            tipText: qsTr("Open menu")
        }
    }

    TitleBar {
        id: titleBar
        titleText: "myExplorer"
        inverted: app.InvertedTheme();

        MouseArea {
            anchors.fill: parent
            onClicked: aboutDialog.open();
        }
    }


    Item
    {
        id: menus
        anchors.fill: parent
        visible: false

        property alias mainMenu: mainMenu
        property alias volMenu1: volMenu1
        property alias volMenu2: volMenu2
        property alias volMenu3: volMenu3

        Menu {
            id: mainMenu
            MenuLayout {
                //MenuItem { text: qsTr("Add network share"); onClicked: cmdAddNetworkFolder(); }
                MenuItem { text: qsTr("About"); onClicked: aboutDialog.open(); }
                MenuItem { text: qsTr("Help"); onClicked: appWindow.showHelp("main_form.html"); }
            }
        }

        ContextMenu
        {
            id: volMenu1
            MenuLayout {
                MenuItem { text: qsTr("Details"); onClicked: app.OnVolDetails(); }
            }

            onStatusChanged: menus.statusChanged(status);
        }

        ContextMenu
        {
            id: volMenu2
            MenuLayout {
                MenuItem { text: qsTr("Remove"); onClicked: app.OnVolRemove(); }
                MenuItem { text: qsTr("Edit"); onClicked: app.OnVolEdit(); }
            }

            onStatusChanged: menus.statusChanged(status);
        }

        ContextMenu
        {
            id: volMenu3
            MenuLayout {
                MenuItem { text: qsTr("Details"); onClicked: app.OnVolDetails(); }
                MenuItem { text: qsTr("Disconnect"); onClicked: app.OnVolDisconnect(); }
            }

            onStatusChanged: menus.statusChanged(status);
        }

        function statusChanged(status)
        {
            if (status == DialogStatus.Closing)
                mainForm.CtxMenuClosed();
        }
    }

    Item {
        id: dlg

        property alias dlgVolDetails: dlgVolDetails

        Loader
        {
            id: dlgVolDetails
            width: parent.width - 20
        }
    }

    QmlMainForm {
        id: mainForm
        anchors.top: titleBar.bottom;
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom

        function cmdShowVolMenu1() { menus.volMenu1.open(); }
        function cmdShowVolMenu2() { menus.volMenu2.open(); }
        function cmdShowVolMenu3() { menus.volMenu3.open(); }

        function cmdShowVolDetailsDialog(title, capacity, free, used, usage)
        {
            if (dlg.dlgVolDetails.status != Loader.Ready)
            {
                //console.log("Loading DiskDetailsDialog");
                dlg.dlgVolDetails.source = "DiskDetailsDialog.qml";
            }

            dlg.dlgVolDetails.item.titleText = title;
            dlg.dlgVolDetails.item.usedText = used;
            dlg.dlgVolDetails.item.freeText = free;
            dlg.dlgVolDetails.item.capacityText = capacity;
            dlg.dlgVolDetails.item.percentUsed = usage;

            dlg.dlgVolDetails.item.open();
        }
    }

    function setInverted() { titleBar.inverted = app.InvertedTheme(); }

    Component.onCompleted: {
        Dynamic.init(app, appWindow);
        app.OnMainFormLoaded(mainForm);
        theme.inverted = app.InvertedTheme();
    }
}
