// MenuItem is a component that is used in menus.

import QtQuick 1.1
import com.nokia.meego 1.1
import "UIConst.js" as UI

Item {
    id: root

    // Common API
    property string text
    signal clicked
    property alias pressed: mouseArea.pressed

    property bool platformSubItemIndicator: false
    property bool privateSelectionIndicator: false

    // platformStyle API
    property Style platformStyle: MenuItemStyle{
        position: root.parent.children.length == 1 ? ""
      : root.parent.children[0] == root ? "vertical-top"
      : root.parent.children[root.parent.children.length-1] == root ? "vertical-bottom"
      : "vertical-center"
    }
    property alias style: root.platformStyle // Deprecated

    width: parent ? parent.width: 0
    height: ( root.platformStyle.height == 0 ) ?
            root.platformStyle.topMargin + menuText.paintedHeight + root.platformStyle.bottomMargin :
            root.platformStyle.topMargin + root.platformStyle.height + root.platformStyle.bottomMargin
/*
    Rectangle {
       id: backgroundRec
       // ToDo: remove hardcoded values
       color: pressed ? "darkgray" : "transparent"
       anchors.fill : root
       opacity : 0.5
    }
*/
    BorderImage {
       id: backgroundImage
       source:   // !enabled ? root.platformStyle.disabledBackground :
                  pressed ? root.platformStyle.pressedBackground
                : root.platformStyle.background
       anchors.fill : root
       border { left: 22; top: 22;
                right: 22; bottom: 22 }
    }

    Text {
        id: menuText
        text: parent.text
        elide: Text.ElideRight
        font.family : root.platformStyle.fontFamily
        font.pixelSize : root.platformStyle.fontPixelSize
        font.weight: root.platformStyle.fontWeight
        color: !root.enabled ? root.platformStyle.disabledTextColor :
                root.pressed ? root.platformStyle.pressedTextColor :
                root.platformStyle.textColor

        anchors.topMargin : root.platformStyle.topMargin
        anchors.bottomMargin : root.platformStyle.bottomMargin
        anchors.leftMargin : root.platformStyle.leftMargin
        anchors.rightMargin : root.platformStyle.rightMargin

        anchors.top : root.platformStyle.centered ? undefined : root.top
        anchors.bottom : root.platformStyle.centered ? undefined : root.bottom
        anchors.left : root.left
        anchors.right: iconLoader.status == Loader.Ready ? iconLoader.left : root.right
//        anchors.centerIn : parent.centerIn
        anchors.verticalCenter : root.platformStyle.centered ? parent.verticalCenter : undefined
  }

    Loader {
        id: iconLoader
        sourceComponent: (root.platformSubItemIndicator || root.privateSelectionIndicator) ? iconComponent : undefined
        anchors {
            right: parent.right
            rightMargin: 12
            verticalCenter: parent.verticalCenter
        }
    }

    Component {
        id: iconComponent

        Image {
            source: {
                if (root.privateSelectionIndicator)
                    return app.InvertedTheme() ? "qrc:/resources/qtg_graf_single_selection_indicator.svg" : "qrc:/resources/qtg_graf_single_selection_indicator_inverse.svg";
                else
                    return app.InvertedTheme() ? "qrc:/resources/qtg_graf_drill_down_indicator.svg" : "qrc:/resources/qtg_graf_drill_down_indicator_inverse.svg";
            }
            sourceSize.width: platformStyle.graphicSizeSmall
            sourceSize.height: platformStyle.graphicSizeSmall
            mirror: LayoutMirroring.enabled
        }
    }

    MouseArea {
        id: mouseArea
        anchors.fill: parent
        onClicked: { if (parent.enabled) parent.clicked();}
    }

    onClicked: if (parent) parent.closeLayout();
}
