import QtQuick 1.1
import com.nokia.meego 1.0

Item {
    id: root
    property url iconSource
    property string platformIconId
    property string tipText
    property bool enabled: true

    // TODO: deprecated
    property alias iconId: root.platformIconId
    width: 80; height: 64
    signal clicked

    // Styling for the ToolItem
    property Style platformStyle: ToolItemStyle{}

    // TODO: deprecated
    property Style style: root.platformStyle

    Image {
        source: (mouseArea.pressed && root.enabled) ? platformStyle.pressedBackground : ""
        anchors.centerIn: parent

        Image {
            function handleIconSource(iconId) {
                if (iconSource != "")
                    return iconSource;

                var prefix = "icon-m-"
                // check if id starts with prefix and use it as is
                // otherwise append prefix and use the inverted version if required
                if (iconId.indexOf(prefix) !== 0)
                    iconId =  prefix.concat(iconId).concat(theme.inverted ? "-white" : "");
                return "image://theme/" + iconId;
            }

            source: handleIconSource(iconId)
            anchors.centerIn: parent
            opacity: root.enabled ? 1.0 : 0.5
        }
    }

    MouseArea {
        id: mouseArea
        anchors.fill: parent
        preventStealing: true

        property variant toolTip: null
        property bool isEnabled: true

        onClicked: if (root.enabled && isEnabled) parent.clicked()
        onPressAndHold: {
            if (!toolTip)
                toolTip = ttComp.createObject(root, {"text": root.tipText, "target": root});

            toolTip.show();
            isEnabled = false;
        }
        onPressedChanged: {
            if (!pressed && toolTip && toolTip.visible) {
                toolTip.hide();
                toolTip.destroy(1000);
                toolTip = null;
                isEnabled = true;
            }
        }
    }

    Component {
        id: ttComp

        ToolTip {
            visible: false
        }
    }
}

