import QtQuick 1.1
import com.nokia.meego 1.0
import myExplorer.types 1.0

Page {
    id: remoteFolderForm
    tools: addFolderTools
    orientationLock:PageOrientation.LockPortrait

    property bool newFolder: true

    ToolBarLayout {
        id: addFolderTools
        visible: false

        ToolButton { text: "Done"; anchors.verticalCenter: parent.verticalCenter;
            anchors.left: parent.left; anchors.leftMargin: 30;
            onClicked:  { if (pageStack.currentPage.onDone()) pageStack.pop(); } }
        ToolButton { text: "Cancel"; anchors.verticalCenter: parent.verticalCenter;
            anchors.right: parent.right; anchors.rightMargin: 30;
            onClicked: pageStack.pop(); }
    }

    TitleBar {
        id: titleBar
        titleText: newFolder ? "Add network folder" : "Edit network folder"
        inverted: app.InvertedTheme();

        Button {
            anchors { top: parent.top; right: parent.right; margins: 6 }
            text: "i"
            height: parent.height - 12
            width: parent.height - 12

            onClicked: appWindow.showHelp("remote_folder_form.html")
        }
    }

    RegExpValidator {
        id: ipValidator
        regExp:/(^$|([1-9][0-9]{0,2})\.([0-9]{0,3})\.([0-9]{0,3})\.([1-9][0-9]{0,2}))/
    }

    SipAttributes
    {
        id: sipAttributes
        actionKeyEnabled: true
        actionKeyHighlighted: true
        actionKeyLabel: "Done"
    }

    Flickable
    {
        id: flickArea
        anchors.top: titleBar.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        contentWidth: parent.width
        contentHeight: 910
        clip: true

        Column
        {
            id: cnt
            anchors.fill: parent
            anchors.leftMargin: 10
            anchors.rightMargin: 10
            spacing: 6

            Row {
                height: 25
                Text { text: " "; }
            }

            Text { font.pixelSize: 24; text: "Computer name"; color: theme.inverted ? "white" : "black" }
            TextField { id: nbtName;
                width: parent.width; inputMethodHints: Qt.ImhNoPredictiveText; platformSipAttributes: sipAttributes;
                Keys.onReturnPressed: { cnt.focus = true; platformCloseSoftwareInputPanel(); }
            }
            Text { font.pixelSize: 24; text: "Folder (share) name (optional)"; color: theme.inverted ? "white" : "black" }
            TextField { id: shareName;
                width: parent.width; inputMethodHints: Qt.ImhNoPredictiveText; platformSipAttributes: sipAttributes;
                Keys.onReturnPressed: { cnt.focus = true; platformCloseSoftwareInputPanel(); }
            }

            Row {
                height: 15
                Text { text: " "; }
            }

            Text { font.pixelSize: 24; text: "User name (optional)"; color: theme.inverted ? "white" : "black" }
            TextField { id: userName;
                width: parent.width; inputMethodHints: Qt.ImhNoPredictiveText + Qt.ImhLowercaseOnly; platformSipAttributes: sipAttributes;
                Keys.onReturnPressed: { cnt.focus = true; platformCloseSoftwareInputPanel(); }
            }
            Text { font.pixelSize: 24; text: "Password (optional)"; color: theme.inverted ? "white" : "black" }
            TextField { id: password;
                width: parent.width; echoMode: TextInput.Password; platformSipAttributes: sipAttributes;
                Keys.onReturnPressed: { cnt.focus = true; platformCloseSoftwareInputPanel(); }
            }

            Row {
                height: 15
                Text { text: " "; }
            }

            Text { font.pixelSize: 24; text: "Computer IP address (optional)"; color: theme.inverted ? "white" : "black" }
            TextField { id: ipAddress;
                width: parent.width; validator: ipValidator; inputMethodHints: Qt.ImhPreferNumbers; platformSipAttributes: sipAttributes;
                Keys.onReturnPressed: { cnt.focus = true; platformCloseSoftwareInputPanel(); }
            }
            Text { font.pixelSize: 24; text: "WINS server IP address (optional)"; color: theme.inverted ? "white" : "black" }
            TextField { id: winsServer;
                width: parent.width; validator: ipValidator; inputMethodHints: Qt.ImhPreferNumbers; platformSipAttributes: sipAttributes;
                Keys.onReturnPressed: { cnt.focus = true; platformCloseSoftwareInputPanel(); }
            }

            Row {
                height: 15
                Text { text: " "; }
            }

            Text { font.pixelSize: 24; text: "Computer DNS name (optional)"; color: theme.inverted ? "white" : "black" }
            TextField { id: dnsName;
                width: parent.width; inputMethodHints: Qt.ImhNoPredictiveText + Qt.ImhLowercaseOnly; platformSipAttributes: sipAttributes;
                Keys.onReturnPressed: { cnt.focus = true; platformCloseSoftwareInputPanel(); }
            }
            Text { font.pixelSize: 24; text: "Port number (optional)"; color: theme.inverted ? "white" : "black" }
            TextField { id: portNumber;
                width: parent.width; inputMethodHints: Qt.ImhDigitsOnly; platformSipAttributes: sipAttributes;
                Keys.onReturnPressed: { cnt.focus = true; platformCloseSoftwareInputPanel(); }
            }
        }
    }

    ScrollDecorator
    {
        flickableItem: flickArea
        anchors.right: parent.right
    }

    //
    // Message boxes
    //

    QueryDialog
    {
        id: dlgErr1

        //titleText: "Exit"
        message: "You must specify computer name, or IP address, or DNS name"
        rejectButtonText: "Close"

        signal privateClicked
        onPrivateClicked: {}
    }

    QueryDialog
    {
        id: dlgErr2

        //titleText: "Exit"
        message: "Invalid IP address"
        rejectButtonText: "Close"

        signal privateClicked
        onPrivateClicked: {}
    }

    QueryDialog
    {
        id: dlgErr3

        //titleText: "Exit"
        message: "Invalid port number"
        rejectButtonText: "Close"

        signal privateClicked
        onPrivateClicked: {}
    }

    function onDone()
    {
        if (nbtName.text.length === 0 && ipAddress.text.length === 0 && dnsName.text.length == 0)
        {
            dlgErr1.open();
            return false;
        }

        if (!ipAddress.acceptableInput || !winsServer.acceptableInput)
        {
            dlgErr2.open();
            return false;
        }

        var port = portNumber.text;
        if (port < 0 || port > 65535)
        {
            dlgErr3.open();
            return false;
        }

        app.OnRemoteFolderFormClosed(nbtName.text.toString(), shareName.text.toString(), userName.text.toString(),
                                     password.text.toString(), ipAddress.text.toString(), winsServer.text.toString(),
                                     dnsName.text.toString(), portNumber.text.toString());

        return true;
    }

    function setForEdit(strName, strShareName, strUserName, strPassword, strIpAddress, strWinsServer, strDnsName, strPort)
    {
        newFolder = false;

        nbtName.text = strName;
        shareName.text = strShareName;
        userName.text = strUserName;
        password.text = strPassword;
        ipAddress.text = strIpAddress;
        winsServer.text = strWinsServer;
        dnsName.text = strDnsName;
        portNumber.text = strPort;
    }
}
