import QtQuick 1.1
import com.nokia.meego 1.0
import myExplorer.types 1.0
import "Dynamic.js" as Dynamic

Page {
    id: textPage

    property variant folderView: null

    tools: commonTools

    ToolBarLayout {
        id: commonTools
        //visible: false

        MilToolButton {
            platformIconId: "toolbar-back"
            onClicked: appWindow.pageStack.pop();
            tipText: "Back"
        }

        MilToolButton {
            iconSource: app.InvertedTheme() ? "qrc:/resources/tbicons/text.svg" : "qrc:/resources/tbicons/text_inverse.svg"
            onClicked: menus.font();
            tipText: "Text options"
        }

        MilToolButton {
            iconSource: app.InvertedTheme() ? "qrc:/resources/tbicons/view_pages.svg" : "qrc:/resources/tbicons/view_pages_inverse.svg"
            onClicked: menus.position();
            tipText: "Go to"
        }

        MilToolButton {
            platformIconId: "toolbar-view-menu"
            onClicked: menus.options();
            tipText: qsTr("Other options")
        }
    }


    //
    // Menus
    //

    Component {
        id: optionsMenuComp

        Menu {
            MenuLayout {
                MenuItem { text: qsTr("Details"); onClicked: textView.DetailsCmd(); }
                MenuItem { text: qsTr("Help"); onClicked: appWindow.showHelp("text_view.html"); }
            }
        }
    }

    Component {
        id: fontMenuComp

        Menu {
            MenuLayout {
                MilMenuItem { text: qsTr("Word wrap"); onClicked: menus.wordWrap(); platformSubItemIndicator: true; }
                MilMenuItem { text: qsTr("Font size"); onClicked: menus.fontSize(); platformSubItemIndicator: true; }
                MilMenuItem { text: qsTr("Colors"); onClicked: menus.colors(); platformSubItemIndicator: true; }
                MilMenuItem { text: qsTr("Encoding"); onClicked: menus.encoding(); platformSubItemIndicator: true; }
            }
        }
    }

    Component {
        id: fontSizeMenuComp

        ContextMenu {
            MenuLayout {
                MilMenuItem { text: qsTr("Very large"); onClicked: textView.SetFontSize(5); }
                MilMenuItem { text: qsTr("Large"); onClicked: textView.SetFontSize(4); }
                MilMenuItem { text: qsTr("Normal"); onClicked: textView.SetFontSize(3); }
                MilMenuItem { text: qsTr("Small"); onClicked: textView.SetFontSize(2); }
                MilMenuItem { text: qsTr("Very small"); onClicked: textView.SetFontSize(1); }
            }
        }
    }

    Component {
        id: wordWrapMenuComp

        ContextMenu {
            MenuLayout {
                MilMenuItem { text: qsTr("Off"); onClicked: textView.SetWordWrap(0); }
                MilMenuItem { text: qsTr("On"); onClicked: textView.SetWordWrap(1); }
                MilMenuItem { text: qsTr("Smart reflow"); onClicked: textView.SetWordWrap(2); }
            }
        }
    }

    Component {
        id: colorsMenuComp

        ContextMenu {
            MenuLayout {
                MilMenuItem { text: qsTr("Default (from the theme)"); onClicked: textView.SetColor(1); }
                MilMenuItem { text: qsTr("Black on white"); onClicked: textView.SetColor(2); }
                MilMenuItem { text: qsTr("White on black"); onClicked: textView.SetColor(3); }
                MilMenuItem { text: qsTr("Green on black"); onClicked: textView.SetColor(4); }
                MilMenuItem { text: qsTr("Night mode"); onClicked: textView.SetColor(5); }
            }
        }
    }

    Component {
        id: encodingMenuComp

        ContextMenu {
            MenuLayout {
                MilMenuItem { text: qsTr("Auto"); onClicked: textView.SetEncoding(0); }
                MilMenuItem { text: qsTr("ASCII / Latin-1"); onClicked: textView.SetEncoding(1); }
                MilMenuItem { text: qsTr("Windows-1252"); onClicked: textView.SetEncoding(2); }
                MilMenuItem { text: qsTr("Cyrillic-1251"); onClicked: textView.SetEncoding(3); }
                MilMenuItem { text: qsTr("Windows-1250"); onClicked: textView.SetEncoding(4); }
                MilMenuItem { text: qsTr("UTF-8"); onClicked: textView.SetEncoding(5); }
                MilMenuItem { text: qsTr("UTF-16 LE"); onClicked: textView.SetEncoding(6); }
                MilMenuItem { text: qsTr("UTF-16 BE"); onClicked: textView.SetEncoding(7); }
            }
        }
    }

    Component {
        id: positionMenuComp

        ContextMenu {
            MenuLayout {
                MenuItem { text: qsTr("Go to top"); onClicked: { textView.GoToTopCmd(); scroller.flash(); } }
                MenuItem { text: qsTr("Go to bottom"); onClicked: { textView.GoToBottomCmd(); scroller.flash(); } }
                MenuItem { text: qsTr("Go to line"); onClicked: dlg.goTo(false); }
                MenuItem { text: qsTr("Go to percent"); onClicked: dlg.goTo(true); }
            }
        }
    }

    QtObject
    {
        id: menus

        property variant aOptions: null
        property variant aFont: null
        property variant aPosition: null
        property variant aFontSize: null
        property variant aWordWrap: null
        property variant aColors: null
        property variant aEncoding: null

        function options() { aOptions = Dynamic.openMenu(aOptions, optionsMenuComp); }
        function font() { aFont = Dynamic.openMenu(aFont, fontMenuComp); }
        function position() { aPosition = Dynamic.openMenu(aPosition, positionMenuComp); }
        function fontSize() { aFontSize = Dynamic.openCheckedMenu(aFontSize, fontSizeMenuComp, 5 - textView.GetFontSize()); }
        function wordWrap() { aWordWrap = Dynamic.openCheckedMenu(aWordWrap, wordWrapMenuComp, textView.GetWordWrap()); }
        function colors() { aColors = Dynamic.openCheckedMenu(aColors, colorsMenuComp, textView.GetColor() - 1); }
        function encoding() { aEncoding = Dynamic.openCheckedMenu(aEncoding, encodingMenuComp, textView.GetEncoding()); }

        function reset() {
            if (aOptions) { aOptions.destroy(); aOptions = null; }
            if (aFont) { aFont.destroy(); aFont = null; }
            if (aPosition) { aPosition.destroy(); aPosition = null; }
            if (fontSize) { fontSize.destroy(); fontSize = null; }
            if (aWordWrap) { aMain.destroy(); aWordWrap = null; }
            if (aColors) { aMain.destroy(); aColors = null; }
            if (aEncoding) { aMain.destroy(); aEncoding = null; }
        }
    }

    TitleBar {
        id: titleBar
        small: true
        titleText: textView.title
        inverted: app.InvertedTheme();

        MouseArea {
            anchors.fill: parent
            onClicked: textView.DetailsCmd();
        }

        function show() {
            visible = true;
            y = 0;
        }

        function hide() {
            y = -titleBar.height;
            visible = false;
        }
    }

    Component {
        id: dlgGoToComp

        Dialog
        {
            property bool percent: false
            property int topLimit

            title: Text { font.pixelSize: 30; font.bold: true; color: "white"; anchors.bottomMargin: 40;
                text: (percent ? "Go to (0% to 100%):" : ("Go to line (1 to " + topLimit + ")"));
                anchors.horizontalCenter: parent.horizontalCenter }

            content: Column {
                id: cnt
                width: parent.width - 20
                x: 10
                spacing: 6

                Row { height: 15; Text { text: " " } }
                TextField { id: pos;
                    width: parent.width; inputMethodHints: Qt.ImhDigitsOnly;
                    validator: IntValidator { bottom: (percent ? 0 : 1); top: topLimit }
                }
                Row { height: 20; Text { text: " " } }
            }

            onStatusChanged: {
                if (status === DialogStatus.Opening) {
                    topLimit = (percent ? 100 : textView.GetLineCount() - 1);
                    pos.text = (percent ? textView.GetCurrentPercent() : textView.GetCurrentLine());
                }
                else if (status === DialogStatus.Open) {
                    pos.forceActiveFocus();
                    pos.platformOpenSoftwareInputPanel();
                }
            }

            buttons: Row {
                spacing: 60
                anchors.horizontalCenter: parent.horizontalCenter

                Button { width: 170; text: "OK"; onClicked: accept(); }
                Button { width: 170; text: "Cancel"; onClicked: reject(); }
            }

            onAccepted: {
                if (percent)
                    textView.GoToPercent(parseInt(pos.text, 10));
                else
                    textView.GoToLine(parseInt(pos.text, 10));

                scroller.flash();
            }
        }
    }

    Component {
        id: aDetailsComp

        TextDetailsDialog {
        }
    }

    QtObject {
        id: dlg

        property variant aGoTo: null
        property variant aDetails: null

        function goTo(percent) {
            aGoTo = Dynamic.loadStyledObject(aGoTo, dlgGoToComp);
            aGoTo.percent = percent;
            aGoTo.open();
        }

        function details() {
            aDetails = Dynamic.loadStyledObject(aDetails, aDetailsComp);
            return aDetails;
        }
    }

    Rectangle {
        id: bkgColor
        anchors.top: titleBar.bottom;
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom

        visible: false
    }

    Style {
        id: sdStyle

        // Background
        property string background: "image://theme/meegotouch-positionindicator-background"
        property string indicator: "image://theme/meegotouch-positionindicator-indicator"
        property string backgroundHorizontal: "image://theme/meegotouch-positionindicator-background-horizontal"
        property string indicatorHorizontal: "image://theme/meegotouch-positionindicator-indicator-horizontal"
    }

    Style {
        id: sdStyleInv

        // Background
        property string background: "image://theme/meegotouch-positionindicator-inverted-background"
        property string indicator: "image://theme/meegotouch-positionindicator-inverted-indicator"
        property string backgroundHorizontal: "image://theme/meegotouch-positionindicator-inverted-background-horizontal"
        property string indicatorHorizontal: "image://theme/meegotouch-positionindicator-inverted-indicator-horizontal"
    }

    Flickable {
        id: flickable
        anchors.top: titleBar.bottom;
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        contentWidth: textView.implicitWidth
        contentHeight: textView.implicitHeight
        pressDelay: 200
        clip: true

        onHeightChanged: textView.OnResize();

        function setBkgColor(enabled, color) {
            if (enabled)
                bkgColor.color = color;
            bkgColor.visible = enabled;
        }

        MouseArea {
            anchors.fill: parent
            onClicked: {
                var mouseY = mouse.y - flickable.contentY;
                if (mouseY < flickable.height / 4) {
                    textView.PageUp();
                    scroller.flash();
                }
                else if (mouseY > 3 * (flickable.height / 4)) {
                    textView.PageDown();
                    scroller.flash();
                }
                else {
                    if (appWindow.showToolBar)
                    {
                        appWindow.showToolBar = false;
                        titleBar.hide();
                    }
                    else
                    {
                        appWindow.showToolBar = true;
                        titleBar.show();
                    }
                }
            }
        }

        QmlTextView {
            id: textView

            function showDetails(name, path, size, saved, pos) {
                var aDlg = dlg.details();
                aDlg.showDialog(name, path, size, saved, pos);
            }

            function setScrollerInverted(inv) { scroller.style = inv ? sdStyle : sdStyleInv }
        }
    }

    ScrollDecorator
    {
        id: scroller
        platformStyle: sdStyle
        //platformInverted: app.InvertedTheme();
        flickableItem: flickable
        anchors.right: parent.right
        anchors.bottom: parent.bottom

        function flash() {
            // Not implemented
        }
    }

    onStatusChanged: {
        if (status === PageStatus.Active) {
            appWindow.showToolBar = true;
            titleBar.show();

            if (!textView.IsInitialized())
            {
                var bLoaded = textView.Initialize(folderView, flickable);

                if (!bLoaded)
                    appWindow.pageStack.pop();
            }
        }
    }

    Component.onCompleted: {
        console.log("Text form loaded");
    }

    Component.onDestruction: console.log("Text form destroyed");
}


