import QtQuick 1.1
import com.nokia.meego 1.0
import myExplorer.types 1.0

MilPageStackWindow {
    id: appWindow

    initialPage: mainPage
    showStatusBar: app.ShowStatusBar();

    MainForm
    {
        id: mainPage
    }

    Item
    {
        id: menus
        anchors.fill: parent
        visible: false

        ContextMenu {
            id: selectMenu
            MenuLayout {
                MenuItem { text: qsTr("Select All"); onClicked: app.OnFolderCmd(101); }
                MenuItem { text: qsTr("Deselect All"); onClicked: app.OnFolderCmd(102); }
                MenuItem { text: qsTr("Invert Selection"); onClicked: app.OnFolderCmd(103); }
            }
        }

        ContextMenu {
            id: editFolderMenu
            MenuLayout {
                MenuItem { text: qsTr("Copy"); onClicked: app.OnFolderCmd(110); }
                MenuItem { text: qsTr("Cut"); onClicked: app.OnFolderCmd(111); }
                MenuItem { text: qsTr("Paste"); onClicked: app.OnFolderCmd(112); }
                MenuItem { text: qsTr("Delete"); onClicked: app.OnFolderCmd(113); }
            }
        }

        Menu {
            id: addFolderMenu
            MenuLayout {
                MenuItem { text: qsTr("Help") }
            }
        }
    }

    Item
    {
        id: dlg
        visible: false

        property alias dlgExit: dlgExit
        property alias msgVolRemove: msgVolRemove
        property alias msgDlg: msgDlg
        property alias dlgSettings: dlgSettings

        //
        // Message boxes
        //

        QueryDialog
        {
            id: dlgExit

            //titleText: "Exit"
            message: "Exit myExplorer?"
            acceptButtonText: "Yes"
            rejectButtonText: "No"

            signal privateClicked
            onPrivateClicked: {}
            onAccepted: Qt.quit();
        }

        QueryDialog
        {
            id: msgVolRemove
            property int volId

            acceptButtonText: "Yes"
            rejectButtonText: "No"

            signal privateClicked
            onPrivateClicked: {}
            onAccepted: app.DoVolRemove(volId);
        }

        QueryDialog
        {
            id: msgDlg
            property string strText
            property int dlgId

            message: strText
            rejectButtonText: "Close"

            signal privateClicked
            onPrivateClicked: {}
            onRejected: if (dlgId != 0) app.OnMsgClosed(dlgId);
        }

        QueryDialog
        {
            id: aboutDialog
            titleText: "myExplorer 2.0"
            message: "Copyright (c) 2011-13 Ilko Tsenov"

            rejectButtonText: "Close"

            signal privateClicked
            onPrivateClicked: {}
        }

        SettingsDialog
        {
            id: dlgSettings
        }

        ViewOptionsDialog
        {
            id: dlgViewOptions
        }

        //
        // Dialogs
        //

        Loader
        {
            id: dlgWait
            width: parent.width
        }

        Loader
        {
            id: dlgRename
            width: parent.width - 20
        }

        Loader
        {
            id: dlgNewFolder
            width: parent.width - 20
        }

        Loader
        {
            id: dlgFilter
            width: parent.width - 20
        }

        Loader
        {
            id: dlgLogin
        }

        Loader
        {
            id: dlgPassword
            width: parent.width - 20
        }

        SelectionDialog
        {
            id: dlgSelShare
            titleText: "Select network share"
            selectedIndex: 0

            model: ListModel {
                id: listModel
             }

            function clearShares() { listModel.clear(); }
            function addShare(share) { listModel.append({"name":share}) }

            onRejected: app.OnShareSelRejected();
            onAccepted: app.OnShareSelAccepted(listModel.get(selectedIndex).name);
        }

        QueryDialog
        {
            id: msgRenameExt
            message: "If you change the file name extension, the file may become unusable.\n\nDo you want to change it?"
            acceptButtonText: "Yes"
            rejectButtonText: "No"

            signal privateClicked
            onPrivateClicked: {}
            onAccepted: app.OnRenameExtAccepted();
        }

        QueryDialog
        {
            id: msgRenameRo
            property alias msg: msgRenameRo.message

            acceptButtonText: "Yes"
            rejectButtonText: "No"

            signal privateClicked
            onPrivateClicked: {}
            onAccepted: app.OnRenameRoAccepted();
        }

        QueryDialog
        {
            id: msgDelete
            property alias msg: msgDelete.message

            acceptButtonText: "Yes"
            rejectButtonText: "No"

            signal privateClicked
            onPrivateClicked: {}
            onAccepted: app.OnDeleteAccepted();
        }

        QueryDialog
        {
            id: msgSelDelete
            property alias msg: msgSelDelete.message

            acceptButtonText: "Yes"
            rejectButtonText: "No"

            signal privateClicked
            onPrivateClicked: {}
            onAccepted: app.OnSelDeleteAccepted();
        }

        Loader
        {
            id: dlgFileDetails
            width: parent.width - 10

            onLoaded: app.OnFileDetailsDlgLoaded(dlgFileDetails.item);
        }

        Loader
        {
            id: dlgSelDetails
            width: parent.width - 10

            onLoaded: app.OnSelDetailsDlgLoaded(dlgSelDetails.item);
        }

        Loader
        {
            id: dlgDelDetails
            width: parent.width - 20

            onLoaded: app.OnDelDetailsDlgLoaded(dlgDelDetails.item);
        }

        OverwriteDialog
        {
            id: dlgOverwrite
            width: parent.width

            Component.onCompleted: app.OnOverwriteDlgLoaded(dlgOverwrite);
        }

        TransferDialog
        {
            id: dlgTransfer
            width: parent.width - 20

            Component.onCompleted: app.OnTransferDlgLoaded(dlgTransfer);
        }
    }

    Component {
        id: helpFormComponent

        HelpForm {
        }
    }

    //
    // Methods
    //

    function cmdExit() {
        if (app.ExitPrompt())
            dlg.dlgExit.open();
        else
            Qt.quit();
    }

    function cmdPop() { appWindow.pageStack.pop(); }

    function cmdOpenFolderForm()
    {
        var form = Qt.createComponent("FolderForm.qml");
        appWindow.pageStack.push(form);
        app.OnFolderFormReady();
    }

    function cmdAddNetworkFolder()
    {
        app.OnVolAdd();
        var form = Qt.createComponent("RemoteFolderForm.qml");
        appWindow.pageStack.push(form);
    }


    function cmdShowVolRemoveMsgBox(msgText, volId)
    {
        dlg.msgVolRemove.message = msgText;
        dlg.msgVolRemove.volId = volId;

        dlg.msgVolRemove.open();
    }

    function cmdLoadFileDetailsDlg()
    {
        if (dlgFileDetails.status != Loader.Ready)
        {
            //console.log("Loading FileDetailsDialog");
            dlgFileDetails.source = "FileDetailsDialog.qml";
        }
    }

    function cmdLoadSelDetailsDlg()
    {
        if (dlgSelDetails.status != Loader.Ready)
        {
            //console.log("Loading SelDetailsDialog");
            dlgSelDetails.source = "SelDetailsDialog.qml";
        }
    }

    function cmdShowSelDetailsDialog() { dlgSelDetails.open(); }

    function cmdLoadDeleteDetailsDlg()
    {
        if (dlgDelDetails.status != Loader.Ready)
        {
            //console.log("Loading DeleteDetailsDialog");
            dlgDelDetails.source = "DeleteDetailsDialog.qml";
        }
    }

    function cmdShowRemoteFolderForm(nbtName, shareName, userName, password, ipAddress, winsServer, dnsName, port)
    {
        var form = Qt.createComponent("RemoteFolderForm.qml");
        appWindow.pageStack.push(form);
        appWindow.pageStack.currentPage.setForEdit(nbtName, shareName, userName, password, ipAddress, winsServer, dnsName, port);
    }

    function cmdShowSettingsDialog()
    {
        dlg.dlgSettings.open();
    }

    function showMsg(titleText, text, dlgid)
    {
        dlg.msgDlg.titleText = titleText;
        dlg.msgDlg.message = text;
        dlg.msgDlg.dlgId = dlgid;
        dlg.msgDlg.open();
    }

    function cmdShowWaitDialog(message, showCancel)
    {
        if (dlgWait.status != Loader.Ready)
        {
            //console.log("Loading WaitDialog");
            dlgWait.source = "WaitDialog.qml";
        }

        dlgWait.item.msgText = message;
        dlgWait.item.showCancel = showCancel;

        dlgWait.item.showDlg();
    }

    function cmdHideWaitDialog()
    {
        if (dlgWait.status == Loader.Ready)
            dlgWait.item.hideDlg();
    }

    function setInvTheme(inv) { theme.inverted = inv; mainPage.setInverted(); }

    function showHelp(pageUrl)
    {
        appWindow.pageStack.push(helpFormComponent, {url: "qrc:/resources/html/" + pageUrl});
    }

    Component {
        id: textFormComponent
        TextPage {
        }
    }

    function cmdOpenTextForm(fv) {
        appWindow.pageStack.push(textFormComponent, {folderView: fv});
    }
}
